@@ -30,6 +30,10 @@
  * EVEN IF SUN HAS BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGES.
  */
 #define _XOPEN_SOURCE 700
+#define _BSD_SOURCE || \
+	(_XOPEN_SOURCE >= 500 || \
+	_XOPEN_SOURCE && _XOPEN_SOURCE_EXTENDED) && \
+	!(_POSIX_C_SOURCE >= 200112L || _XOPEN_SOURCE >= 600)
 
 #include <stdlib.h>
 #include <stdio.h>
@@ -69,6 +73,8 @@
 #include <ipmitool/ipmi_oem.h>
 #include <ipmitool/ipmi_ekanalyzer.h>
 #include <ipmitool/ipmi_picmg.h>
+#include <ipmitool/ipmi_kontronoem.h>
+#include <ipmitool/ipmi_vita.h>
 
 #ifdef HAVE_CONFIG_H
 # include <config.h>
@@ -80,6 +86,10 @@
 # define OPTION_STRING	"I:46hVvcH:f:U:p:d:S:D:"
 #endif
 
+/* From src/plugins/ipmi_intf.c: */
+void
+ipmi_intf_set_max_request_data_size(struct ipmi_intf * intf, uint16_t size);
+
 extern int verbose;
 extern int csv_output;
 extern const struct valstr ipmi_privlvl_vals[];
@@ -332,7 +342,7 @@ ipmi_parse_hex(const char *str)
 		else /* it's A-F or a-f */
 			b = (*p | 0x20) - 'a' + 10; /* convert to lowercase and to 10-15 */
 
-		*q = *q + b << shift;
+		*q = *q + (b << shift);
 		if (shift)
 			shift = 0;
 		else {
