@@ -267,7 +267,7 @@ ipmi_pef_print_lan_dest(struct ipmi_intf * intf, uint8_t ch, uint8_t dest)
 	struct pef_lan_cfgparm_dest_type * ptype;
 	struct pef_lan_cfgparm_dest_info * pinfo;
 	char buf[32];
-	uint8_t tbl_size, dsttype, timeout, retries;
+	uint8_t dsttype, timeout, retries;
 
 	memset(&lsel, 0, sizeof(lsel));
 	lsel.id = PEF_LAN_CFGPARM_ID_DEST_COUNT;
@@ -283,9 +283,6 @@ ipmi_pef_print_lan_dest(struct ipmi_intf * intf, uint8_t ch, uint8_t dest)
 			"Alert destination count");
 		return;
 	}
-	tbl_size = (rsp->data[1] & PEF_LAN_DEST_TABLE_SIZE_MASK);
-	//if (tbl_size == 0 || dest == 0)	/* LAN alerting not supported */
-	//	return;
 
 	lsel.id = PEF_LAN_CFGPARM_ID_DESTTYPE;
 	lsel.set = dest;
