@@ -30,6 +30,7 @@
  * EVEN IF SUN HAS BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGES.
  */
 #define _XOPEN_SOURCE 700
+#define _BSD_SOURCE
 
 #include <stdio.h>
 #include <fcntl.h>
@@ -70,7 +71,7 @@
 # else
 #  include "plugins/open/open.h"
 # endif
-#  include <sys/poll.h>
+#  include <poll.h>
 #endif /* IPMI_INTF_OPEN */
 
 #include <ipmitool/helper.h>
